{% extends "base.html" %}

{% block extrahead %}
<link rel="stylesheet" href="{{ url_for('static', filename="css/index.css") }}" type="text/css" media="screen, projection">
{% endblock %}

{% block body %}
<div class="span-11 colborder">
    <h2>Installed databases</h2>
    <p>(click on a database to get more options)</p>
    <table id="installed-databases">
        <thead>
            <tr>
                <th>Name</th>
                <th>Version</th>
                <th># activities</th>
            </tr>
        </thead>
        <tbody>{% for row in databases %}
            <tr>
                <td>{{row.name}}</td>
                <td>{{row.version}}</td>
                <td>{{row.number}}</td>
            </tr>{% endfor %}
        </tbody>
    </table>
</div>
<div class="span-12 last">
    <p>Data directory is <i>{{ config.udir }}</i></p>
</div>
<div class="span-6">
    <a href="/lca"><button>Calculate LCA</button></a><br>
    <a href="/settings"><button>Change settings</button></a><br>
    <a href="https://brightway2.readthedocs.org/en/latest/"><button>Documentation</button></a>
</div>
<div class="span-6 last">
    <a href="/import/database"><button>Import database</button></a><br>
    <!-- <a href="/export/database"><button>Export database</button></a><br> -->
    <button>Export database</button><br>
    <a href="/import/method"><button>Import LCIA method</button></a>
</div>
<hr>
<h2>Installed LCIA methods</h2>
<p>(click on a method to get more options)</p>
<table id="installed-methods">
    <thead>
        <tr>
            <th>Name</th>
            <th>Unit</th>
            <th># CFs</th>
        </tr>
    </thead>
    <tbody>{% for row in methods %}
        <tr>
            <td>{{row.name}}</td>
            <td>{{row.unit}}</td>
            <td>{{row.num_cfs}}</td>
        </tr>{% endfor %}
    </tbody>
</table>

<script type="text/javascript">
$('#installed-databases').dataTable({
    "bLengthChange": false,
    "bJQueryUI": true
});
$('#installed-methods').dataTable({
    "bJQueryUI": true
});
</script>
{% endblock %}
